/*
 * DS Lightbox system plugin for Joomla! 2.5 & 3.x
 * Version   2.0
 * URL: http://dzyanis.com/myprojects/dslightbox
 * The lightbox engine taken from next source (MIT License):
 * https://github.com/duncanmcdougall/Responsive-Lightbox
 * Some modifications have been done by DS.
 */
 
// Initiate Lightbox
jQuery(function() {
  jQuery('.ds-lb').ds_lightbox(); // 'gallery' to 'ds-lb' <- [DS]
});

(function (jQuery) {

    'use strict';

    jQuery.fn.ds_lightbox = function (options) {

        var opts = {
			margin: 0,
			nav: true,
			navLoop: false, //  <- [DS]
			blur: false,
			fadeIn_speed: 'fast', //  <- [DS]
			fadeOut_speed: 'fast', //  <- [DS]
			minSize: 0,
			ds_prev: '<< Previous', //  <- [DS]
			ds_next: 'Next >>', //  <- [DS]
			ds_close: 'Click to close' //  <- [DS]
        };

        var plugin = {

            items: [],
            ds_lightbox: null,
            image: null,
            current: null,
            locked: false,
            caption: null,
			
            init: function (items) {
                plugin.items = items;
                var id = 'ds-lightbox-' + Math.floor((Math.random() * 100000) + 1);
                if (!plugin.ds_lightbox) {
                    plugin.ds_lightbox = jQuery('body').find('.bodyGlobalLightbox');

                    if(plugin.ds_lightbox.length === 0){
                        jQuery('body').append(
                          '<div id="'+id+'" class="ds-lightbox bodyGlobalLightbox" style="display:none;">'+
                          '<span title="'+opts.ds_close+'" class="ds-lightbox_close ds-lightbox_button"></span>' + //  <- [DS]
                          '<span title="'+opts.ds_prev+'" class="ds-lightbox_nav ds-lightbox_nav--prev ds-lightbox_button"></span>' + //  <- [DS]
                          '<span title="'+opts.ds_next+'" class="ds-lightbox_nav ds-lightbox_nav--next ds-lightbox_button"></span>' + //  <- [DS]
                          '<div href="#" class="ds-lightbox_caption"><p></p></div>' +
                          '</div>'
                        );

                        plugin.ds_lightbox = jQuery("#"+id);
                    }

                    plugin.caption = jQuery('.ds-lightbox_caption', plugin.ds_lightbox);
                }

                if (plugin.items.length > 1 && opts.nav) {
                    jQuery('.ds-lightbox_nav', plugin.ds_lightbox).show();
                } else {
                    jQuery('.ds-lightbox_nav', plugin.ds_lightbox).hide();
                }

                plugin.bindEvents();

            },

            loadImage: function () {
                if(opts.blur) {
                    jQuery("body").addClass("blurred");
                }
                jQuery("img", plugin.ds_lightbox).remove();
                plugin.ds_lightbox.fadeIn(opts.fadeIn_speed).append('<span class="ds-lightbox_loading"></span>'); //  <- [DS]

                var img = jQuery('<img src="' + jQuery(plugin.current).attr('src') + '" draggable="false">'); // 'href' to 'src' <- [DS]

                jQuery(img).load(function () {
                    jQuery('.ds-lightbox_loading').remove();
                    plugin.ds_lightbox.append(img);
                    plugin.image = jQuery("img", plugin.ds_lightbox).hide();
                    plugin.resizeImage();
                    plugin.setCaption();
					
					// loop navigation: [DS]
					if (!opts.navLoop) {
						if (plugin.getCurrentIndex() >= plugin.items.length - 1) {
							jQuery('.ds-lightbox_nav--next', plugin.ds_lightbox).hide();
						}else{
							jQuery('.ds-lightbox_nav--next', plugin.ds_lightbox).show();
						}
						if (plugin.getCurrentIndex() <= 0) {
							jQuery('.ds-lightbox_nav--prev', plugin.ds_lightbox).hide();
						}else{
							jQuery('.ds-lightbox_nav--prev', plugin.ds_lightbox).show();
						}
					}	
					// End of loop navigation [DS]
                });
            },

            setCaption: function () {
				
				// Image description logic: [DS]
				//var caption = $(plugin.current).data('caption');
				var ds_alt = jQuery(plugin.current).attr('alt');
				var ds_title = jQuery(plugin.current).attr('title');
				
				//if (caption == undefined || caption == ''){
					if 	(ds_title != undefined && ds_title != '') {
						var caption = ds_title;
					} else {
						if 	(ds_alt != undefined && ds_alt != '' && ds_title != '')	{
							var caption = ds_alt;
						}
					}
				//}
				// End of Image description logic [DS]
				
                
				
                if(!!caption && caption.length > 0) {
                    plugin.caption.fadeIn(); //  <- [DS]
                    jQuery('p', plugin.caption).text(caption);
                }else{
                    plugin.caption.hide();
                }
				
            },

            resizeImage: function () {
                var ratio, wHeight, wWidth, iHeight, iWidth;
                wHeight = jQuery(window).height() - opts.margin;
                wWidth = jQuery(window).outerWidth(true) - opts.margin;
                plugin.image.width('').height('');
                iHeight = plugin.image.height();
                iWidth = plugin.image.width();
                if (iWidth > wWidth) {
                    ratio = wWidth / iWidth;
                    iWidth = wWidth;
                    iHeight = Math.round(iHeight * ratio);
                }
                if (iHeight > wHeight) {
                    ratio = wHeight / iHeight;
                    iHeight = wHeight;
                    iWidth = Math.round(iWidth * ratio);
                }

                plugin.image.width(iWidth).height(iHeight).css({
						'top': (jQuery(window).height() - plugin.image.outerHeight()) / 2 + 'px',
						'left': (jQuery(window).width() - plugin.image.outerWidth()) / 2 + 'px'
					}).show();
                plugin.locked = false;
            },

            getCurrentIndex: function () {
                return jQuery.inArray(plugin.current, plugin.items);
            },

            next: function () {
                if (plugin.locked) {
                    return false;
                }
                plugin.locked = true;
                if (plugin.getCurrentIndex() >= plugin.items.length - 1) {
                    jQuery(plugin.items[0]).click();
                } else {
                    jQuery(plugin.items[plugin.getCurrentIndex() + 1]).click();
                }
            },

            previous: function () {
                if (plugin.locked) {
                    return false;
                }
                plugin.locked = true;
                if (plugin.getCurrentIndex() <= 0) {
                    jQuery(plugin.items[plugin.items.length - 1]).click();
                } else {
                    jQuery(plugin.items[plugin.getCurrentIndex() - 1]).click();
                }
            },

            bindEvents: function () {
                jQuery(plugin.items).click(function (e) {
                    if(!plugin.ds_lightbox.is(":visible") && (jQuery(window).width() < opts.minSize || jQuery(window).height() < opts.minSize)) {
                        jQuery(this).attr("target", "_blank");
                        return;
                    }
                    var self = jQuery(this)[0];
                    e.preventDefault();
                    plugin.current = self;
                    plugin.loadImage();

                    // Bind Keyboard Shortcuts
                    jQuery(document).on('keydown', function (e) {
                        // CLOSE lightbox with ESC
                        if (e.keyCode === 27) {
                            plugin.close();
                        }
                        // Go to NEXT image pressing the right key
						if (e.keyCode === 39 && !(!opts.navLoop && plugin.getCurrentIndex() >= plugin.items.length - 1) ) { // <- [DS]
							plugin.next();
                        }
                        // Go to PREVIOUS image pressing the left key
                        if (e.keyCode === 37 && !(!opts.navLoop && (plugin.getCurrentIndex() <= 0))) { //   <- [DS]
                            plugin.previous();
                        }
                    });
                });

                // Add click state
                plugin.ds_lightbox.on('click', function (e) {
                    //if (this === e.target) { // <-  on overlay background only [DS]
                        plugin.close();
                    //} // <-  on overlay background only [DS]
                });

                // Previous click
                jQuery(plugin.ds_lightbox).on('click', '.ds-lightbox_nav--prev', function () {
                    plugin.previous();
                    return false;
                });

                // Next click
                jQuery(plugin.ds_lightbox).on('click', '.ds-lightbox_nav--next', function () {
                    plugin.next();
                    return false;
                });

                // Close click
                jQuery(plugin.ds_lightbox).on('click', '.ds-lightbox_close', function () {
                    plugin.close();
                    return false;
                });

                jQuery(window).resize(function () {
                    if (!plugin.image) {
                        return;
                    }
                    plugin.resizeImage();
                });
            },

            close: function () {
                jQuery(document).off('keydown'); // Unbind all key events each time the lightbox is closed
                jQuery(plugin.ds_lightbox).fadeOut(opts.fadeOut_speed);
                jQuery('body').removeClass('blurred');
            }
        };

        jQuery.extend(opts, options);

        plugin.init(this);
    };

})(jQuery);